Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ColorMode ¶
type ColorMode int
func DetectMode ¶
DetectMode determines the effective color mode for auto-detection.
Priority order (first match wins):
- TERM=dumb suppresses colors entirely.
- NO_COLOR disables colors.
- CLICOLOR=0 disables colors.
- CLICOLOR_FORCE / FORCE_COLOR with any non-zero value force-enable colors.
- Otherwise colors are emitted only when stdout is a TTY.
type Profile ¶
type Profile int
func DetectProfile ¶
DetectProfile inspects COLORTERM/TERM to determine the best-fit color profile. truecolor/24-bit environments get TrueColor, *256color terminals get ANSI256, TERM=dumb and any other terminal names fall back to the basic 8-color profile.
type Style ¶
func HeaderStyle ¶
func HeaderStyle() Style
Click to show internal directories.
Click to hide internal directories.